@@ -3,8 +3,8 @@ from __future__ import annotations
 import urwid
 
 
-def show_or_exit(key):
-    if key in ("q", "Q"):
+def show_or_exit(key: str) -> None:
+    if key in {"q", "Q"}:
         raise urwid.ExitMainLoop()
     txt.set_text(repr(key))
 
