@@ -493,24 +493,13 @@ def is_mouse_press(ev: str) -> bool:
 
 
 class MetaSuper(type):
-    """adding .__super"""
+    """Deprecated metaclass.
 
-    def __init__(cls, name: str, bases, d):
-        super().__init__(name, bases, d)
-        if hasattr(cls, f"_{name}__super"):
-            raise AttributeError("Class has same name as one of its super classes")
+    Present only for code compatibility, all logic has been removed.
+    Please move to the last position in the class bases to allow future changes.
+    """
 
-        @property
-        def _super(self):
-            warnings.warn(
-                f"`{name}.__super` was a deprecated feature for old python versions."
-                f"Please use `super()` call instead.",
-                DeprecationWarning,
-                stacklevel=3,
-            )
-            return super(cls, self)
-
-        setattr(cls, f"_{name}__super", _super)
+    __slots__ = ()
 
 
 def int_scale(val: int, val_range: int, out_range: int) -> int:
@@ -521,7 +510,7 @@ def int_scale(val: int, val_range: int, out_range: int) -> int:
 
     >>> "%x" % int_scale(0x7, 0x10, 0x10000)
     '7777'
-    >>> "%x" % int_scale(0x5f, 0x100, 0x10)
+    >>> "%x" % int_scale(0x5F, 0x100, 0x10)
     '6'
     >>> int_scale(2, 6, 101)
     40
@@ -534,7 +523,7 @@ def int_scale(val: int, val_range: int, out_range: int) -> int:
     return num // dem
 
 
-class StoppingContext(typing.ContextManager["StoppingContext"]):
+class StoppingContext(contextlib.AbstractContextManager["StoppingContext"]):
     """Context manager that calls ``stop`` on a given object on exit.  Used to
     make the ``start`` method on `MainLoop` and `BaseScreen` optionally act as
     context managers.
